regrtest: rename --slow option to --slowest

Thanks to optparse, --slow syntax still works ;-)
diff --git a/Lib/test/libregrtest/cmdline.py b/Lib/test/libregrtest/cmdline.py
index f2ec0bd..1f7aaed 100644
--- a/Lib/test/libregrtest/cmdline.py
+++ b/Lib/test/libregrtest/cmdline.py
@@ -168,7 +168,7 @@
                        help='display test output on failure')
     group.add_argument('-q', '--quiet', action='store_true',
                        help='no output unless one or more tests fail')
-    group.add_argument('-o', '--slow', action='store_true', dest='print_slow',
+    group.add_argument('-o', '--slowest', action='store_true', dest='print_slow',
                        help='print the slowest 10 tests')
     group.add_argument('--header', action='store_true',
                        help='print header with interpreter info')
diff --git a/Lib/test/test_regrtest.py b/Lib/test/test_regrtest.py
index 32edff8..4a96c6f 100644
--- a/Lib/test/test_regrtest.py
+++ b/Lib/test/test_regrtest.py
@@ -109,7 +109,7 @@
                 self.assertEqual(ns.verbose, 0)
 
     def test_slow(self):
-        for opt in '-o', '--slow':
+        for opt in '-o', '--slowest':
             with self.subTest(opt=opt):
                 ns = libregrtest._parse_args([opt])
                 self.assertTrue(ns.print_slow)
@@ -661,9 +661,9 @@
         self.check_executed_tests(output, test, omitted=test)
 
     def test_slow(self):
-        # test --slow
+        # test --slowest
         tests = [self.create_test() for index in range(3)]
-        output = self.run_tests("--slow", *tests)
+        output = self.run_tests("--slowest", *tests)
         self.check_executed_tests(output, tests)
         regex = ('10 slowest tests:\n'
                  '(?:%s: [0-9]+\.[0-9]+s\n){%s}'
@@ -671,15 +671,15 @@
         self.check_line(output, regex)
 
     def test_slow_interrupted(self):
         # Issue #25373: test --slow with an interrupted test
         code = TEST_INTERRUPTED
         test = self.create_test("sigint", code=code)
 
         for multiprocessing in (False, True):
             if multiprocessing:
-                args = ("--slow", "-j2", test)
+                args = ("--slowest", "-j2", test)
             else:
-                args = ("--slow", test)
+                args = ("--slowest", test)
             output = self.run_tests(*args, exitcode=1)
             self.check_executed_tests(output, test, omitted=test)
             regex = ('10 slowest tests:\n')
@@ -671,15 +671,15 @@
 
     def test_slow_interrupted(self):
-        # Issue #25373: test --slow with an interrupted test
+        # Issue #25373: test --slowest with an interrupted test
         code = TEST_INTERRUPTED
         test = self.create_test("sigint", code=code)